@@ -404,9 +404,11 @@ class RubiconTest(unittest.TestCase):
             + (
                 r"TypeError: 'float' object cannot be interpreted as an integer; argtypes: c_int"
                 if sys.version_info >= (3, 12)
-                else r"TypeError: wrong type; argtypes: c_int"
-                if sys.version_info >= (3, 10)
-                else r"<class 'TypeError'>: wrong type; argtypes: c_int"
+                else (
+                    r"TypeError: wrong type; argtypes: c_int"
+                    if sys.version_info >= (3, 10)
+                    else r"<class 'TypeError'>: wrong type; argtypes: c_int"
+                )
             ),
         ):
             obj.mutateIntFieldWithValue_(1.234)
@@ -984,6 +986,33 @@ class RubiconTest(unittest.TestCase):
         )
         self.assertEqual(buf.value.decode("utf-8"), pystring)
 
+    def test_objcmethod_str_repr(self):
+        """Test ObjCMethod, ObjCPartialMethod, and ObjCBoundMethod str and repr"""
+
+        obj = NSObject.new()
+
+        # ObjCMethod
+        self.assertEqual(repr(obj.init.method), "<ObjCMethod: init @16@0:8>")
+        self.assertEqual(str(obj.init.method), "<ObjCMethod: init @16@0:8>")
+
+        # ObjCBoundMethod
+        self.assertRegex(
+            repr(obj.init),
+            r"ObjCBoundMethod\(<ObjCMethod: init @16@0:8>, <NSObject: 0x[0-9a-f]{12}>\)",
+        )
+        self.assertRegex(
+            str(obj.init),
+            r"ObjCBoundMethod\(<ObjCMethod: init @16@0:8>, <NSObject: 0x[0-9a-f]{12}>\)",
+        )
+
+        # ObjCPartialMethod
+        self.assertEqual(
+            repr(obj.performSelector.method), "ObjCPartialMethod('performSelector')"
+        )
+        self.assertEqual(
+            str(obj.performSelector.method), "ObjCPartialMethod('performSelector')"
+        )
+
     def test_objcinstance_str_repr(self):
         """An ObjCInstance's str and repr contain the object's description and
         debugDescription, respectively."""
@@ -995,8 +1024,15 @@ class RubiconTest(unittest.TestCase):
             py_description_string,
             debugDescriptionString=py_debug_description_string,
         )
+
+        # Check str
         self.assertEqual(str(tester), py_description_string)
-        self.assertIn(py_debug_description_string, repr(tester))
+
+        # Check repr
+        self.assertEqual(
+            repr(tester),
+            f"<ObjCInstance: DescriptionTester at {hex(id(tester))}: {py_debug_description_string}>",
+        )
 
     def test_objcinstance_str_repr_with_nil_descriptions(self):
         """An ObjCInstance's str and repr work even if description and
@@ -1009,6 +1045,17 @@ class RubiconTest(unittest.TestCase):
         self.assertIsNot(str(tester), None)
         self.assertIsNot(repr(tester), None)
 
+    def test_objcclass_repr(self):
+        """Test ObjCClass repr and str return correct value."""
+
+        self.assertEqual(repr(NSObject), "<ObjCClass: NSObject>")
+        self.assertEqual(str(NSObject), "ObjCClass('NSObject')")
+
+    def test_objcprotocol_repr(self):
+        """Test ObjCProtocol repr return correct value."""
+
+        self.assertEqual(repr(NSObjectProtocol), "<ObjCProtocol: NSObject>")
+
     def test_nspoint_repr(self):
         """Test NSPoint repr and str returns correct value."""
 
@@ -1116,6 +1163,115 @@ class RubiconTest(unittest.TestCase):
             class MyClass(NSObject):  # noqa: F811
                 pass
 
+    def test_class_auto_rename_global(self):
+        """Test the global automatic renaming option of ObjCClass."""
+
+        try:
+            ObjCClass.auto_rename = True
+
+            class TestGlobalRenamedClass(NSObject):
+                @objc_method
+                def oldMethod(self):
+                    pass
+
+            class1 = TestGlobalRenamedClass
+
+            class TestGlobalRenamedClass_2(NSObject):
+                pass
+
+            class TestGlobalRenamedClass(NSObject):  # noqa: F811
+                @objc_method
+                def testMethod(self):
+                    return "TEST1"
+
+            # Check that the class was renamed
+            self.assertEqual(TestGlobalRenamedClass.name, "TestGlobalRenamedClass_3")
+            self.assertIsNot(class1, TestGlobalRenamedClass)
+
+            # Check that methods are updated
+            obj = TestGlobalRenamedClass.new()
+            with self.assertRaises(AttributeError):
+                obj.oldMethod()
+            self.assertEqual(obj.testMethod(), "TEST1")
+
+        finally:
+            ObjCClass.auto_rename = False
+
+    def test_class_auto_rename_per_class(self):
+        """Test the per-class automatic renaming option of ObjCClass."""
+
+        class TestLocalRenamedClass(NSObject):
+            @objc_method
+            def oldMethod(self):
+                pass
+
+        class1 = TestLocalRenamedClass
+
+        class TestLocalRenamedClass_2(NSObject):
+            pass
+
+        class TestLocalRenamedClass(NSObject, auto_rename=True):  # noqa: F811
+            @objc_method
+            def testMethod(self):
+                return "TEST2"
+
+        # Check that the class was renamed
+        self.assertEqual(TestLocalRenamedClass.name, "TestLocalRenamedClass_3")
+        self.assertIsNot(class1, TestLocalRenamedClass)
+
+        # Check that methods are updated
+        obj = TestLocalRenamedClass.new()
+        with self.assertRaises(AttributeError):
+            obj.oldMethod()
+        self.assertEqual(obj.testMethod(), "TEST2")
+
+    def test_protocol_auto_rename_global(self):
+        """Test the global automatic renaming option of ObjCProtocol."""
+
+        try:
+            ObjCProtocol.auto_rename = True
+
+            class TestGlobalRenamedProtocol(metaclass=ObjCProtocol):
+                pass
+
+            protocol1 = TestGlobalRenamedProtocol
+
+            class TestGlobalRenamedProtocol_2(metaclass=ObjCProtocol):
+                pass
+
+            class TestGlobalRenamedProtocol(metaclass=ObjCProtocol):  # noqa: F811
+                pass
+
+            # Check that the protocol was renamed
+            self.assertEqual(
+                TestGlobalRenamedProtocol.name, "TestGlobalRenamedProtocol_3"
+            )
+            self.assertIsNot(protocol1, TestGlobalRenamedProtocol)
+
+        finally:
+            ObjCProtocol.auto_rename = False
+
+    def test_protocol_auto_rename_per_class(self):
+        """Test the per-protocol automatic renaming option of ObjCProtocol."""
+
+        class TestLocalRenamedProtocol(metaclass=ObjCProtocol):
+            pass
+
+        protocol1 = TestLocalRenamedProtocol
+
+        class TestLocalRenamedProtocol_2(metaclass=ObjCProtocol):
+            pass
+
+        class TestLocalRenamedProtocol(
+            metaclass=ObjCProtocol,
+            auto_rename=True,
+        ):  # noqa: F811
+            pass
+
+        # Check that the protocol was renamed
+        self.assertEqual(TestLocalRenamedProtocol.name, "TestLocalRenamedProtocol_3")
+        self.assertIsNot(protocol1, TestLocalRenamedProtocol)
+
     def test_interface(self):
         """An ObjC protocol implementation can be defined in Python."""
 
